diff Framework/Scene2DViewport/ViewportController.h @ 1308:adf234ecaa00 broker

Merge
author Benjamin Golinvaux <bgo@osimis.io>
date Wed, 04 Mar 2020 10:21:54 +0100
parents 8a28a9bf8876 c38c89684d83
children ab81ee8fce1f
line wrap: on
line diff
--- a/Framework/Scene2DViewport/ViewportController.h	Wed Mar 04 10:07:37 2020 +0100
+++ b/Framework/Scene2DViewport/ViewportController.h	Wed Mar 04 10:21:54 2020 +0100
@@ -26,6 +26,8 @@
 #include "../Scene2D/Scene2D.h"
 #include "../Scene2DViewport/IFlexiblePointerTracker.h"
 
+#include <Core/Compatibility.h>
+
 #include <boost/enable_shared_from_this.hpp>
 #include <stack>
 
@@ -232,9 +234,9 @@
     IViewport&                                    viewport_;
     boost::weak_ptr<UndoStack>                    undoStackW_;  // Global stack, possibly shared by all viewports
     std::vector<boost::shared_ptr<MeasureTool> >  measureTools_;
-    boost::shared_ptr<IFlexiblePointerTracker>    activeTracker_;  // TODO - Couldn't this be a "std::auto_ptr"?
+    boost::shared_ptr<IFlexiblePointerTracker>    activeTracker_;  // TODO - Couldn't this be a "std::unique_ptr"?
 
-    std::auto_ptr<Scene2D>   scene_;
+    std::unique_ptr<Scene2D>   scene_;
 
     // this is cached
     double  canvasToSceneFactor_;